@@ -28,14 +28,17 @@ class Application(Neo4jCsvSerializable):
                  task_id,  # type: str
                  dag_id,  # type: str,
                  application_url_template,  # type: str
-                 exec_date,  # type: str
+                 db_name='hive',  # type: str
+                 schema='',  # type: str
+                 table_name='',  # type: str
+                 exec_date='',  # type: str
                  ):
         # type: (...) -> None
         self.task = task_id
 
         # todo: need to modify this hack
         self.application_url = application_url_template.format(dag_id=dag_id)
-        self.database, self.schema, self.table = task_id.split('.')
+        self.database, self.schema, self.table = db_name, schema, table_name
 
         self.dag = dag_id
 
